/*******************************************************************************
* File Name: BoardLEDOut.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "BoardLEDOut.h"


/*******************************************************************************
* Function Name: BoardLEDOut_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void BoardLEDOut_Write(uint8 value) 
{
    uint8 staticBits = (BoardLEDOut_DR & (uint8)(~BoardLEDOut_MASK));
    BoardLEDOut_DR = staticBits | ((uint8)(value << BoardLEDOut_SHIFT) & BoardLEDOut_MASK);
}


/*******************************************************************************
* Function Name: BoardLEDOut_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  BoardLEDOut_DM_STRONG     Strong Drive 
*  BoardLEDOut_DM_OD_HI      Open Drain, Drives High 
*  BoardLEDOut_DM_OD_LO      Open Drain, Drives Low 
*  BoardLEDOut_DM_RES_UP     Resistive Pull Up 
*  BoardLEDOut_DM_RES_DWN    Resistive Pull Down 
*  BoardLEDOut_DM_RES_UPDWN  Resistive Pull Up/Down 
*  BoardLEDOut_DM_DIG_HIZ    High Impedance Digital 
*  BoardLEDOut_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void BoardLEDOut_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(BoardLEDOut_0, mode);
}


/*******************************************************************************
* Function Name: BoardLEDOut_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro BoardLEDOut_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 BoardLEDOut_Read(void) 
{
    return (BoardLEDOut_PS & BoardLEDOut_MASK) >> BoardLEDOut_SHIFT;
}


/*******************************************************************************
* Function Name: BoardLEDOut_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 BoardLEDOut_ReadDataReg(void) 
{
    return (BoardLEDOut_DR & BoardLEDOut_MASK) >> BoardLEDOut_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(BoardLEDOut_INTSTAT) 

    /*******************************************************************************
    * Function Name: BoardLEDOut_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 BoardLEDOut_ClearInterrupt(void) 
    {
        return (BoardLEDOut_INTSTAT & BoardLEDOut_MASK) >> BoardLEDOut_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
