/*******************************************************************************
* File Name: LED4ctrl.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "LED4ctrl.h"


/*******************************************************************************
* Function Name: LED4ctrl_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void LED4ctrl_Write(uint8 value) 
{
    uint8 staticBits = (LED4ctrl_DR & (uint8)(~LED4ctrl_MASK));
    LED4ctrl_DR = staticBits | ((uint8)(value << LED4ctrl_SHIFT) & LED4ctrl_MASK);
}


/*******************************************************************************
* Function Name: LED4ctrl_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  LED4ctrl_DM_STRONG     Strong Drive 
*  LED4ctrl_DM_OD_HI      Open Drain, Drives High 
*  LED4ctrl_DM_OD_LO      Open Drain, Drives Low 
*  LED4ctrl_DM_RES_UP     Resistive Pull Up 
*  LED4ctrl_DM_RES_DWN    Resistive Pull Down 
*  LED4ctrl_DM_RES_UPDWN  Resistive Pull Up/Down 
*  LED4ctrl_DM_DIG_HIZ    High Impedance Digital 
*  LED4ctrl_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void LED4ctrl_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(LED4ctrl_0, mode);
}


/*******************************************************************************
* Function Name: LED4ctrl_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro LED4ctrl_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 LED4ctrl_Read(void) 
{
    return (LED4ctrl_PS & LED4ctrl_MASK) >> LED4ctrl_SHIFT;
}


/*******************************************************************************
* Function Name: LED4ctrl_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 LED4ctrl_ReadDataReg(void) 
{
    return (LED4ctrl_DR & LED4ctrl_MASK) >> LED4ctrl_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(LED4ctrl_INTSTAT) 

    /*******************************************************************************
    * Function Name: LED4ctrl_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 LED4ctrl_ClearInterrupt(void) 
    {
        return (LED4ctrl_INTSTAT & LED4ctrl_MASK) >> LED4ctrl_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
